# Shower HTML presentation engine

Follow [@shower_me](https://twitter.com/shower_me) for support and updates

To see Shower in action:

- Open [shwr.me](http://shwr.me/)
- Click any slide to enter presentation mode
- Use arrow keys or presenter remote to navigate
- Press `Esc` to exit presentation mode

See [Wiki](https://github.com/shower/shower/wiki) for more information how to use Shower.

## Using Shower

There are two ways of making presentation using Shower: you can just download an archive with all you need or you can install needed Shower modules using [npm](https://www.npmjs.org) or [bower](http://bower.io).

### Simple Way

In a simple way you just download the latest Shower version with built-in themes and use it.

1. Download and unarchive [shower.zip](http://shwr.me/shower.zip)
2. Open `index.html` in any code or text editor, edit your slides in HTML
3. Use `pictures` folder for pictures used in presentation
4. Once finished, open `index.html` in a browser, enter full screen and start presenting

### Advanced Way

Advanced way allows you to manually install needed Shower packages and requires [Node.js](http://nodejs.org/) installed together with package managment system: `npm` or `bower`.

1. Run `npm install shower-core shower-ribbon`
2. Link core and theme files in `node_modules` folder to your presentation file
3. You’re probably know what to do next, it’s an advanced way.

**Note:** you can use `bower` instead of `npm` or `shower-bright` instead of `shower-ribbon` in command above to install Shower using Bower or get Bright theme.

## Usage examples

- [Clear and Sharp](http://pepelsbey.net/pres/clear-and-sharp/)
- [CSS Management](http://pepelsbey.net/pres/knife-train/)
- [Push it!](http://pepelsbey.net/pres/push-it/)
- [Pre-fixes](http://pepelsbey.net/pres/pre-fixes/)
- [Web In Curves](http://pepelsbey.net/pres/web-in-curves/)
- [Sense Coding](http://pepelsbey.net/pres/sense-coding/)

## Browser support

Latest stable versions of Chrome, Internet Explorer, Firefox, Opera and Safari are supported.

## Contributing

You’re always welcome to contibute. Fork project, make changes and send it as pull request. But it’s better to file an [issue](https://github.com/shower/shower/issues) with your idea first. Read [contributing rules](https://github.com/shower/shower/blob/master/Contributing.md) for more details.

Main contributors: [pepelsbey](https://github.com/pepelsbey), [jahson](https://github.com/jahson), [miripiruni](https://github.com/miripiruni), [kizu](https://github.com/kizu), [artpolikarpov](https://github.com/artpolikarpov), [tonyganch](https://github.com/tonyganch).

---
Licensed under [MIT License](http://en.wikipedia.org/wiki/MIT_License), see [license page](https://github.com/shower/shower/wiki/MIT-License) for details.